@@ -1,6 +1,8 @@
 import base64
 import hmac
 import json
+import os
+import threading
 import time
 import uuid
 from hashlib import sha1
@@ -31,6 +33,23 @@ class MqttSendMessageException(WinhyeException):
 
 
 class MqttClint:
+    _instance = None
+    lock = threading.Lock()
+
+    def __new__(cls, *args, **kwargs):
+        """
+        设置为单例以保证线程中client一致安全
+        :param args:
+        :param kwargs:
+        """
+        if cls._instance:
+
+            return cls._instance
+        else:
+            with cls.lock:
+                cls._instance = super().__new__(cls)
+                return cls._instance
+
     def __init__(self, mqtt_config: dict):
         """
         topic 在start之前确定就可用
@@ -47,8 +66,12 @@ class MqttClint:
         secret_key = mqtt_config["AccessKey_Secret"]
         instance_id = mqtt_config["instance_id"]
         group_id = mqtt_config["group_id"]
-        # client_id不能重复，所以使用当前时间
-        self.client_id = group_id + '@@@' + str(uuid.uuid1())
+        # client_id不能重复，使用自定义字符串 app_id-env-idc-pid(进程id)
+        app_id = os.environ.get("APP_ID", str(uuid.uuid1())[:10])
+        env = os.environ.get("ENV", str(uuid.uuid1())[:10])
+        idc = os.environ.get("IDC", str(uuid.uuid1())[:10])
+        pid = os.getpid()
+        self.client_id = f"{group_id}@@@{app_id}-{env}-{idc}-{pid}"
         username = 'Signature' + '|' + access_key + '|' + instance_id
         password = base64.b64encode(hmac.new(secret_key.encode(), self.client_id.encode(), sha1).digest()).decode()
 
