@@ -1,6 +1,8 @@
 import os
 import sys
+import threading
 import time
+from multiprocessing import Process, Value, Array
 
 PATH = os.path.abspath(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
 sys.path.append(PATH)
@@ -9,7 +11,7 @@ print(PATH)
 from src.winhye_common.mqtt.mqtt_base import MqttClint, MqttSendMessageException
 
 
-def mqtt_test():
+def mqtt_test(index):
     mqtt_config = {
         "broker": "mqtt-cn-i7m2ceaxt07.mqtt.aliyuncs.com",
         "port": 1883,
@@ -28,14 +30,29 @@ def mqtt_test():
         }
     }
     handler = MqttClint(mqtt_config)
-    time.sleep(1)
+    # t1 = threading.Thread(target=handler.client.loop_forever)
+    # t1.setDaemon(True)
+    # t1.start()
+    # time.sleep(20)
+
     try:
         while True:
             handler.send_message("send_kaifa/AGV-S/aa", data)
-            time.sleep(60)
+            # print(index, handler.client_id, handler)
+            time.sleep(2)
     except MqttSendMessageException:
         print(111111111111111111)
 
 
 if __name__ == '__main__':
-    mqtt_test()
+    # mqtt_test(1)
+    p = Process(target=mqtt_test, args=(1,))
+    p2 = Process(target=mqtt_test, args=(2,))
+    print('Child process will start.')
+    p.start()
+    p2.start()
+    p.join()
+    p2.join()
+    print("end")
+
+
